@@ -39,7 +39,34 @@ class EntryRepository extends EntityRepository
         return $this
             ->getSortedQueryBuilderByUser($userId)
             ->andWhere('e.isArchived = false')
-        ;
+            ;
+    }
+
+    /**
+     * Retrieves entries with the same domain.
+     *
+     * @param int $userId
+     * @param int $entryId
+     *
+     * @return QueryBuilder
+     */
+    public function getBuilderForSameDomainByUser($userId, $entryId)
+    {
+        $queryBuilder = $this->createQueryBuilder('e');
+
+        return $this
+            ->getSortedQueryBuilderByUser($userId)
+            ->andWhere('e.id <> :entryId')->setParameter('entryId', $entryId)
+            ->andWhere(
+                $queryBuilder->expr()->in(
+                    'e.domainName',
+                    $this
+                        ->createQueryBuilder('e2')
+                        ->select('e2.domainName')
+                        ->where('e2.id = :entryId')->setParameter('entryId', $entryId)
+                        ->getDQL()
+                )
+            );
     }
 
     /**
@@ -115,6 +142,21 @@ class EntryRepository extends EntityRepository
         return $this->sortQueryBuilder($this->getRawBuilderForUntaggedByUser($userId));
     }
 
+    /**
+     * Retrieve entries with annotations for a user.
+     *
+     * @param int $userId
+     *
+     * @return QueryBuilder
+     */
+    public function getBuilderForAnnotationsByUser($userId)
+    {
+        return $this
+            ->getSortedQueryBuilderByUser($userId)
+            ->innerJoin('e.annotations', 'a')
+            ;
+    }
+
     /**
      * Retrieve untagged entries for a user.
      *
@@ -343,9 +385,9 @@ class EntryRepository extends EntityRepository
      *
      * @return array
      */
-    public function findAllByTagId($userId, $tagId)
+    public function findAllByTagId($userId, $tagId, $sort = 'createdAt')
     {
-        return $this->getSortedQueryBuilderByUser($userId)
+        return $this->getSortedQueryBuilderByUser($userId, $sort)
             ->innerJoin('e.tags', 't')
             ->andWhere('t.id = :tagId')->setParameter('tagId', $tagId)
             ->getQuery()
@@ -552,6 +594,10 @@ class EntryRepository extends EntityRepository
                 $qb->leftJoin('e.tags', 't');
                 $qb->andWhere('t.id is null');
                 break;
+            case 'annotated':
+                $qb->leftJoin('e.annotations', 'a');
+                $qb->andWhere('a.id is not null');
+                break;
         }
 
         $ids = $qb->getQuery()->getArrayResult();
